@@ -1,5 +1,5 @@
 import sys
-import six
+from django.utils import six
 
 from dbsettings.values import Value
 from dbsettings.loading import register_setting, unregister_setting
@@ -13,6 +13,7 @@ class GroupBase(type):
             return
         attrs.pop('__module__', None)
         attrs.pop('__doc__', None)
+        attrs.pop('__qualname__', None)
         for attribute_name, attr in attrs.items():
             if not isinstance(attr, Value):
                 raise TypeError('The type of %s (%s) is not a valid Value.' %
