@@ -1,11 +1,12 @@
 from __future__ import unicode_literals
-import six
+from django.utils import six
 
 import datetime
 from decimal import Decimal
 from hashlib import md5
 from os.path import join as pjoin
 import time
+import os
 
 from django import forms
 from django.conf import settings
@@ -306,7 +307,10 @@ class ImageValue(Value):
         hashed_name = md5(six.text_type(time.time())).hexdigest() + value.name[-4:]
         image_path = pjoin(self._upload_to, hashed_name)
         dest_name = pjoin(settings.MEDIA_ROOT, image_path)
+        directory = pjoin(settings.MEDIA_ROOT, self._upload_to)
 
+        if not os.path.exists(directory):
+            os.makedirs(directory)
         with open(dest_name, 'wb+') as dest_file:
             for chunk in value.chunks():
                 dest_file.write(chunk)
